lilypondfiletools.BookBlock
===========================

.. abjad-lineage:: abjad.tools.lilypondfiletools.BookBlock.BookBlock

.. autoclass:: abjad.tools.lilypondfiletools.BookBlock.BookBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.append
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.count
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.extend
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.index
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.insert
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.pop
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.remove
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.reverse
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.sort
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__add__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__contains__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__delitem__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__delslice__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__eq__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__format__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__ge__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__getitem__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__getslice__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__gt__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__iadd__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__imul__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__iter__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__le__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__len__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__lt__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__mul__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__ne__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__repr__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__reversed__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__rmul__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__setitem__
      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.__setslice__
   :noindex:
